@@ -4,6 +4,10 @@ import pymongo
 from tornado.options import options
 from tweb import time
 from bson.objectid import ObjectId
+import base64
+import logging
+from webmother import passport, identity
+import webmother
 
 MongoDB = {
     'active': True,  # 是否启用
@@ -36,7 +40,6 @@ catalog = None
 org = None
 org2user = None
 catalog2org = None
-vip = None
 
 
 def init():
@@ -49,7 +52,6 @@ def init():
     global org
     global org2user
     global catalog2org
-    global vip
 
     mongo_cfg = MongoDB[options.env]
 
@@ -68,14 +70,12 @@ def init():
     org = mongo_db.org
     org2user = mongo_db.org2user
     catalog2org = mongo_db.catalog2org
-    vip = mongo_db.vip
 
     # 创建索引
     _catalog_index()
     _org_index()
     _org2user_index()
     _catalog2org_index()
-    _vip_index()
 
     # 初始化系统数据
     _init_data()
@@ -169,29 +169,14 @@ def _catalog2org_index():
     catalog2org.create_index('org')
 
 
-def _vip_index():
-    """
-    只有注册开通了vip会员，才能接收客户端自主注册
-    {
-        "_id": ObjectId('5c85c9f9e155ac04c9f5ec42'),
-        "app_org": ObjectId('5c85ca15e155ac04c9f5ec43'),        # 申请开通向客户开放服务应用的组织ID
-        "vip_org": ObjectId('5c85ca52e155ac04c9f5ec44'),        # 接收开放会员注册的组织ID，必须是app_org组织下的子组织
-        "level": 0,                                             # VIP组的级别
-        "identity": 'member:0000;;|org:000000000;0;',           # 会员身份定义
-        "created": 1551074929275,
-        "updated": 1551074929275
-    }
-    """
-    vip.create_index('app_org')
-    vip.create_index('vip_org')
-
-
 def _init_data():
     now = time.millisecond()
 
     world_catalog = catalog.find_one({'node': 'world'})
     if world_catalog is None:
+        world_cid = ObjectId('a' * 24)
         result = catalog.insert_one({
+            "_id": world_cid,
             "node": "world",
             "status": 30,
             "display": {
@@ -205,25 +190,32 @@ def _init_data():
 
     god_org = org.find_one({'node': 'god'})
     if god_org is None:
+        god_oid = ObjectId('0' * 24)
+        god_appid = str(base64.b32encode(god_oid.binary), encoding="utf8")[0:20]
         result = org.insert_one({
+            "_id": god_oid,
             "node": "god",
             "status": 30,
             "display": {
                 "zh": "系统管理",
                 "en": "Administration"
             },
+            "appid": god_appid,
             "created": now,
             "updated": now
         })
         god_org = org.find_one({'_id': result.inserted_id})
 
+    logging.info('God\'s appid is %s' % god_org['appid'])
+    print('God\'s appid is %s' % god_org['appid'])
+
     c2o = catalog2org.find_one({'catalog': world_catalog['_id'], 'org': god_org['_id']})
     if c2o is None:
         catalog2org.insert_one({
             "catalog": world_catalog['_id'],
             "catalog_node": world_catalog['node'],
             "org": god_org['_id'],
-            "passport": "catalog:111111111;-10;|grant:1111;;",
+            "passport": webmother.max_lic_text,
             "created": now,
             "updated": now
         })
@@ -239,7 +231,8 @@ def _init_data():
             "org": god_org['_id'],
             "org_node": god_org['node'],
             "user": big_god,
-            "identity": "member:1111;;|org:111111111;-10;",
+            "identity": identity.max_lic_text,
+            "member_type": 0,
             "created": now,
             "updated": now
         })
