@@ -3,7 +3,7 @@
 import config
 from webmother.http_handler import catalog_handler as h
 
-base = '{}/{}/catalog'.format(config.VER, config.DOMAIN)
+base = '{}/{}/catalog'.format(config.VER, config.PLATFORM)
 routes = [
     # 分类节点的增删改查，增时参数会解析成父节点ID，删改查时则解析成本节点
     (rf"/{base}/([a-f0-9]*)", h.CatalogHandler),
