@@ -19,4 +19,12 @@ routes = [
     # 查询组织拥有哪些资源的许可证/通行证，许可范围有多大
     (rf"/{base}/([a-f0-9]*)/passports", h.OurPassportsHandler),
 
+    # 创建应用，生成appid
+    (rf"/{base}/([a-f0-9]*)/app", h.AppHandler),
+
+    # 针对客户添加会员组
+    (rf"/{base}/vip", h.VipHandler),
+
+    # 查询会员组列表
+    (rf"/{base}/vip/list", h.VipsHandler),
 ]
