@@ -34,6 +34,26 @@ async def move(oid, oid_to, *auth_args):
     return await get_event_loop().run_in_executor(None, ctrl_org.move, *args)
 
 
-async def our_passports(oid, *auth_args):
+async def our_passports(oid, system, *auth_args):
+    args = (oid, system, *auth_args)
+    return await get_event_loop().run_in_executor(None, ctrl_org.our_passports, *args)
+
+
+async def app_activate(oid, *auth_args):
     args = (oid, *auth_args)
-    return await get_event_loop().run_in_executor(None, ctrl_org.our_passports, *args)
\ No newline at end of file
+    return await get_event_loop().run_in_executor(None, ctrl_org.app_activate, *args)
+
+
+async def appid_deactivate(oid, *auth_args):
+    args = oid, *auth_args
+    return await get_event_loop().run_in_executor(None, ctrl_org.appid_deactivate, *args)
+
+
+async def vip_create(appid, level, display, *auth_args):
+    args = appid, level, display, *auth_args
+    return await get_event_loop().run_in_executor(None, ctrl_org.vip_create, *args)
+
+
+async def vip_query(appid, *auth_args):
+    args = appid, *auth_args
+    return await get_event_loop().run_in_executor(None, ctrl_org.vip_query, *args)
