@@ -4,9 +4,8 @@ from webmother.service import ctrl_passport
 from asyncio import get_event_loop
 
 
-async def get_passport_tpl(cid, *auth_args):
-    args = cid, *auth_args
-    return await get_event_loop().run_in_executor(None, ctrl_passport.get_passport_tpl, *args)
+async def get_passport_tpl():
+    return await get_event_loop().run_in_executor(None, ctrl_passport.get_passport_tpl)
 
 
 async def passport_create(cid, oid, passport_json, *auth_args):
@@ -14,8 +13,8 @@ async def passport_create(cid, oid, passport_json, *auth_args):
     return await get_event_loop().run_in_executor(None, ctrl_passport.passport_create, *args)
 
 
-async def passport_read(cid, oid, *auth_args):
-    args = cid, oid, *auth_args
+async def passport_read(cid, oid):
+    args = cid, oid
     return await get_event_loop().run_in_executor(None, ctrl_passport.passport_read, *args)
 
 
@@ -29,6 +28,6 @@ async def passport_remove(cid, oid, *auth_args):
     return await get_event_loop().run_in_executor(None, ctrl_passport.passport_remove, *args)
 
 
-async def passports_query(cid, *auth_args):
-    args = (cid, *auth_args)
+async def passports_query(cid):
+    args = (cid,)
     return await get_event_loop().run_in_executor(None, ctrl_passport.passports_query, *args)
