@@ -5,7 +5,7 @@ from tweb.json_util import filter_keys
 from tweb.error_exception import ErrException, ERROR
 from tweb import time
 from bson.objectid import ObjectId
-from webmother.service.passport import Passport
+from webmother.passport import Passport
 import re
 
 
@@ -58,9 +58,7 @@ def create(cid, cata_meta, *auth_args):
     if not re.match(r'^[\w]{0,19}$', name):
         raise ErrException(ERROR.E40000, extra='name should be letter, number, _, and beginning with letter')
 
-    parent_node = c['node']
-
-    cata_meta['node'] = f'{parent_node}/{name}'
+    cata_meta['node'] = '{}/{}'.format(c['node'], name)
     cata_meta['parent'] = ObjectId(cid)
 
     if db.catalog.find_one({'node': cata_meta['node'], 'status': {'$gte': 0}}) is not None:
@@ -86,8 +84,8 @@ def read(cid, *auth_args):
 
 
 def simple_read(cid, raw=False):
-    if cid is None:
-        raise ErrException(ERROR.E40000, extra='invalid cid')
+    if not ObjectId.is_valid(cid):
+        raise ErrException(ERROR.E40000, extra='invalid cid %s' % cid)
 
     c = db.catalog.find_one({'_id': ObjectId(cid), 'status': {'$gte': 0}})
     if c is None:
@@ -162,7 +160,8 @@ def children(cid, *auth_args):
     c = simple_read(cid)
 
     # 授权检查
-    pp = Passport().verify(*auth_args).operable(c.get('node'), 'catalog.read')
+    # 因为授权限制操作授权本级节点，故在这里加一个'/children'，表示是读取子节点
+    pp = Passport().verify(*auth_args).operable('{}/children'.format(c.get('node')), 'catalog.read')
     visible_level = pp.number(c.get('node'), 'catalog.visible_level')
     min_stat = Status.activated - visible_level
     # END
@@ -193,8 +192,8 @@ def move(cid, cid_to, *auth_args):
         raise ErrException(ERROR.E40000, extra='the same node, not need move')
 
     # 授权检查
-    Passport().verify(*auth_args).operable(c['node'], 'catalog.remove', 'grant.remove')
-    Passport().verify(*auth_args).operable(c_to['node'], 'catalog.create', 'grant.create')
+    Passport().verify(*auth_args).operable(c['node'], 'catalog.remove')
+    Passport().verify(*auth_args).operable(c_to['node'], 'catalog.create')
     # END
 
     if c['status'] not in (Status.editing, Status.auditing, Status.sleeping, Status.activated):
@@ -223,8 +222,8 @@ def move(cid, cid_to, *auth_args):
     # 还需要同步修改与此节点相关catalog2org记录，因为里面记录了节点的node值。多个地方更新需要用到事务！
     with db.start_session() as s:
         s.start_transaction()
-        db.catalog2org.update_many({'catalog': ObjectId(cid)}, {'$set': tmp_c2o})
-        db.catalog.update_one({'_id': ObjectId(cid)}, {'$set': tmp_c})
+        db.catalog2org.update_many({'catalog': ObjectId(cid)}, {'$set': tmp_c2o}, session=s)
+        db.catalog.update_one({'_id': ObjectId(cid)}, {'$set': tmp_c}, session=s)
         s.commit_transaction()
 
     return simple_read(cid)
