@@ -4,7 +4,7 @@ from webmother.db import mongo as db
 from tweb.error_exception import ErrException, ERROR
 from tweb import time
 from bson.objectid import ObjectId
-from webmother.service.identity import Identity
+from webmother.identity import Identity
 from webmother.service import ctrl_org
 
 from ucenter.services import ctrl_user
@@ -62,6 +62,7 @@ def member_create(oid, indicator, identity_json, *auth_args):
         "org": ObjectId(oid),
         "org_node": node,
         "identity": Identity().update(node, uid, identity_json, idt).text,
+        "member_type": 0,
         "user": user,
         "created": now,
         "updated": now
