@@ -5,17 +5,15 @@ from tweb.error_exception import ErrException, ERROR
 from tweb import time
 from bson.objectid import ObjectId
 from webmother.service import ctrl_catalog, ctrl_org
-from webmother.service.passport import Passport
+from webmother.passport import Passport
 
 
-def get_passport_tpl(cid, *auth_args):
-    c = ctrl_catalog.read(cid, *auth_args)
-
-    # 授权检查
-    Passport().verify(*auth_args).operable(c.get('node'), 'grant.create')
-    # END
-
-    return Passport().json
+def get_passport_tpl():
+    pp = Passport()
+    return {
+        'passport': pp.json,
+        'passport_display': pp.display
+    }
 
 
 def passport_create(cid, oid, passport_json, *auth_args):
@@ -27,10 +25,10 @@ def passport_create(cid, oid, passport_json, *auth_args):
     :param auth_args: 鉴权参数：(signed, nonce), 即("签名的授权字符串", "临时一致性标示，需与生成签名时使用的nonce相同")
     :return:
     """
-    c = ctrl_catalog.read(cid, *auth_args)
+    c = ctrl_catalog.simple_read(cid)
 
     # 授权检查
-    pp = Passport().verify(*auth_args).operable(c.get('node'), 'grant.create')
+    pp = Passport().verify(*auth_args)
     # END
 
     with db.start_session() as s:
@@ -46,7 +44,7 @@ def passport_create(cid, oid, passport_json, *auth_args):
 
             # 如果已经授权该组织给下级节点，则首先删除，再添加（相当于移动，升级到更高级资源节点）
             if other.find(node) == 0:
-                db.catalog2org.delete_one({'catalog': item['catalog'], 'org': ObjectId(oid)})
+                db.catalog2org.delete_one({'catalog': item['catalog'], 'org': ObjectId(oid)}, session=s)
 
         now = time.millisecond()
         db.catalog2org.insert_one({
@@ -56,32 +54,24 @@ def passport_create(cid, oid, passport_json, *auth_args):
             "passport": Passport().update(node, oid, passport_json, pp).text,
             "created": now,
             "updated": now
-        })
+        }, session=s)
         # end
         s.commit_transaction()
 
-    return _passport_read(cid, oid)
+    return passport_read(cid, oid)
 
 
-def passport_read(cid, oid, *auth_args):
-    c = ctrl_catalog.read(cid, *auth_args)
-
-    # 授权检查
-    Passport().verify(*auth_args).operable(c.get('node'), 'grant.read')
-    # END
-
-    return _passport_read(cid, oid)
-
-
-def _passport_read(cid, oid):
-    c2o = db.catalog2org.find_one({'catalog': ObjectId(cid), 'org': ObjectId(oid)})
+def passport_read(cid, oid):
+    c2o = db.catalog2org.find_one({'catalog': ObjectId(cid), 'org': ObjectId(oid)}, {'_id': 0})
     if c2o is None:
         raise ErrException(ERROR.E40400)
 
-    c2o['ppid'] = c2o.pop('_id').__str__()
     c2o['catalog'] = c2o['catalog'].__str__()
     c2o['org'] = ctrl_org.simple_read(c2o['org'])
-    c2o['passport'] = Passport().parse(c2o['passport']).json
+
+    pp = Passport().parse(c2o['passport'])
+    c2o['passport'] = pp.json
+    c2o['passport_display'] = pp.display
 
     return c2o
 
@@ -95,10 +85,10 @@ def passport_update(cid, oid, passport_json, *auth_args):
     :param auth_args: 鉴权参数：(signed, nonce), 即("签名的授权字符串", "临时一致性标示，需与生成签名时使用的nonce相同")
     :return:
     """
-    c = ctrl_catalog.read(cid, *auth_args)
+    c = ctrl_catalog.simple_read(cid)
 
     # 授权检查
-    pp = Passport().verify(*auth_args).operable(c.get('node'), 'grant.update')
+    pp = Passport().verify(*auth_args)
     # END
 
     c2o = db.catalog2org.find_one({'catalog': ObjectId(cid), 'org': ObjectId(oid)})
@@ -110,7 +100,7 @@ def passport_update(cid, oid, passport_json, *auth_args):
     temp['updated'] = time.millisecond()
     db.catalog2org.update_one({'_id': c2o['_id']}, {'$set': temp})
 
-    return _passport_read(cid, oid)
+    return passport_read(cid, oid)
 
 
 def passport_remove(cid, oid, *auth_args):
@@ -121,39 +111,35 @@ def passport_remove(cid, oid, *auth_args):
     :param auth_args: 鉴权参数：(signed, nonce), 即("签名的授权字符串", "临时一致性标示，需与生成签名时使用的nonce相同")
     :return:
     """
-    c = ctrl_catalog.read(cid, *auth_args)
+    c = ctrl_catalog.simple_read(cid)
 
-    # 授权检查
-    Passport().verify(*auth_args).operable(c.get('node'), 'grant.remove')
-    # END
+    # 将所有权限关闭（内部会检查是否有操作的权限）
+    # passport_update(cid, oid, Passport()., *auth_args)
 
     # 使已签名的授权无效
     Passport.invalidate_signed(c['node'], oid)
 
+    # 最后删除记录
     db.catalog2org.delete_one({'catalog': ObjectId(cid), 'org': ObjectId(oid)})
 
     return {}
 
 
-def passports_query(cid, *auth_args):
+def passports_query(cid):
     """
     获取分类节点的被授权的组织列表
     :param cid:
-    :param auth_args: 鉴权参数：(signed, nonce), 即("签名的授权字符串", "临时一致性标示，需与生成签名时使用的nonce相同")
     :return:
     """
-    c = ctrl_catalog.read(cid, *auth_args)
-
-    # 授权检查
-    Passport().verify(*auth_args).operable(c.get('node'), 'grant.read')
-    # END
-
-    cursor = db.catalog2org.find({'catalog': ObjectId(cid)}, {'catalog': 0})
+    cursor = db.catalog2org.find({'catalog': ObjectId(cid)}, {'_id': 0, 'catalog': 0})
     array = list()
+    display = None
     for item in cursor:
-        item['ppid'] = item.pop('_id').__str__()
         item['org'] = ctrl_org.simple_read(item['org'])
-        item['passport'] = Passport().parse(item['passport']).json
+        pp = Passport().parse(item['passport'])
+        item['passport'] = pp.json
+        if display is None:
+            display = pp.display
         array.append(item)
 
-    return array
+    return array, display
